<?xml version="1.0" encoding="UTF-8" ?>
<!-- This file handles variable definitions -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="xml" encoding="UTF-8"
    doctype-system="http://www.springframework.org/dtd/spring-beans.dtd"
    doctype-public="-//SPRING//DTD BEAN//EN"
    cdata-section-elements="beans" />

  <!-- Default stage table names -->
  <xsl:variable name="ST_SITES">DS_SITES</xsl:variable>

  <!-- Staging Field names -->
  <xsl:variable name="sitename_field">sitename</xsl:variable>
  <xsl:variable name="site_status_field">site_status</xsl:variable>
  <xsl:variable name="site_language_field">site_language</xsl:variable>
  <xsl:variable name="site_timezone_field">site_timezone</xsl:variable>
  <xsl:variable name="site_address_01_field">site_address_01</xsl:variable>
  <xsl:variable name="site_address_02_field">site_address_02</xsl:variable>
  <xsl:variable name="site_city_field">site_city</xsl:variable>
  <xsl:variable name="site_country_field">site_country</xsl:variable>
  <xsl:variable name="site_region_name_field">site_region_name</xsl:variable>
  <xsl:variable name="site_mail_code_field">site_mail_code</xsl:variable>
  <xsl:variable name="site_cluster_01_field">site_cluster_01</xsl:variable>
  
  <!-- Site .. Table Level -->
  <xsl:template match="site">
    <bean>
      <xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
      </xsl:attribute>
      <xsl:call-template name="inject_staging_datasource" />
      <xsl:call-template name="choose_staging_table_name">
        <xsl:with-param name="default_name" select="$ST_SITES" />
      </xsl:call-template>
      <property name="dataSynchronizationService">
        <ref bean="dataSyncSiteService" />
      </property>
      <xsl:call-template name="inject_report_keeper"/>
      <!-- Row Synchronizer -->
      <xsl:call-template name="row_synchronizer">
        <xsl:with-param name="data_synchronization_service">dataSyncSiteService</xsl:with-param>
        <xsl:with-param name="default_table" select="$ST_SITES" />
      </xsl:call-template>
    </bean>
  </xsl:template>

  <!-- Field Level -->
  <xsl:template match="sitename">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">name</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
      <xsl:with-param name="validatorBean">uniqueSiteNameValidator</xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="site_status">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">status</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$statusTypeMapper" />
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="site_language">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">language</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$referenceKeyTypeMapper" />
      <xsl:with-param name="mapper_properties">dataSyncLanguageService</xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="site_timezone">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">timezone</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$referenceKeyTypeMapper" />
      <xsl:with-param name="mapper_properties">dataSyncTimeZoneService</xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="site_address_01">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="synchronizer_class" select="$enterprise_address_field_synchronizer"/>
      <xsl:with-param name="model_property_name">lineOne</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="site_address_02">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="synchronizer_class" select="$enterprise_address_field_synchronizer"/>
      <xsl:with-param name="model_property_name">lineTwo</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="site_city">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="synchronizer_class" select="$enterprise_address_field_synchronizer"/>
      <xsl:with-param name="model_property_name">cityName</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="site_country">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="synchronizer_class" select="$enterprise_address_field_synchronizer"/>
      <xsl:with-param name="model_property_name">country</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$referenceKeyTypeMapper" />
      <xsl:with-param name="mapper_properties">dataSyncCountryService</xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="site_region_name">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="synchronizer_class" select="$enterprise_address_field_synchronizer"/>
      <xsl:with-param name="model_property_name">regionName</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="site_mail_code">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="synchronizer_class" select="$enterprise_address_field_synchronizer"/>
      <xsl:with-param name="model_property_name">mailCode</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="site_cluster_01">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">primaryCluster</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$referenceKeyTypeMapper" />
      <xsl:with-param name="mapper_properties">dataSyncClusterService</xsl:with-param>
    </xsl:call-template>
  </xsl:template>

</xsl:stylesheet>
